@@ -79,9 +79,10 @@ var annotated_dup =
             [ "Schwarz", "classgko_1_1experimental_1_1distributed_1_1preconditioner_1_1Schwarz.html", "classgko_1_1experimental_1_1distributed_1_1preconditioner_1_1Schwarz" ]
           ] ],
           [ "DistributedBase", "classgko_1_1experimental_1_1distributed_1_1DistributedBase.html", "classgko_1_1experimental_1_1distributed_1_1DistributedBase" ],
-          [ "index_map", "structgko_1_1experimental_1_1distributed_1_1index__map.html", "structgko_1_1experimental_1_1distributed_1_1index__map" ],
+          [ "index_map", "classgko_1_1experimental_1_1distributed_1_1index__map.html", "classgko_1_1experimental_1_1distributed_1_1index__map" ],
           [ "Matrix", "classgko_1_1experimental_1_1distributed_1_1Matrix.html", "classgko_1_1experimental_1_1distributed_1_1Matrix" ],
           [ "Partition", "classgko_1_1experimental_1_1distributed_1_1Partition.html", "classgko_1_1experimental_1_1distributed_1_1Partition" ],
+          [ "RowGatherer", "classgko_1_1experimental_1_1distributed_1_1RowGatherer.html", "classgko_1_1experimental_1_1distributed_1_1RowGatherer" ],
           [ "Vector", "classgko_1_1experimental_1_1distributed_1_1Vector.html", "classgko_1_1experimental_1_1distributed_1_1Vector" ]
         ] ],
         [ "factorization", null, [
@@ -90,9 +91,12 @@ var annotated_dup =
           [ "Lu", "classgko_1_1experimental_1_1factorization_1_1Lu.html", "classgko_1_1experimental_1_1factorization_1_1Lu" ]
         ] ],
         [ "mpi", "namespacegko_1_1experimental_1_1mpi.html", [
+          [ "CollectiveCommunicator", "classgko_1_1experimental_1_1mpi_1_1CollectiveCommunicator.html", "classgko_1_1experimental_1_1mpi_1_1CollectiveCommunicator" ],
           [ "communicator", "classgko_1_1experimental_1_1mpi_1_1communicator.html", "classgko_1_1experimental_1_1mpi_1_1communicator" ],
           [ "contiguous_type", "classgko_1_1experimental_1_1mpi_1_1contiguous__type.html", "classgko_1_1experimental_1_1mpi_1_1contiguous__type" ],
+          [ "DenseCommunicator", "classgko_1_1experimental_1_1mpi_1_1DenseCommunicator.html", "classgko_1_1experimental_1_1mpi_1_1DenseCommunicator" ],
           [ "environment", "classgko_1_1experimental_1_1mpi_1_1environment.html", "classgko_1_1experimental_1_1mpi_1_1environment" ],
+          [ "NeighborhoodCommunicator", "classgko_1_1experimental_1_1mpi_1_1NeighborhoodCommunicator.html", "classgko_1_1experimental_1_1mpi_1_1NeighborhoodCommunicator" ],
           [ "request", "classgko_1_1experimental_1_1mpi_1_1request.html", "classgko_1_1experimental_1_1mpi_1_1request" ],
           [ "status", "structgko_1_1experimental_1_1mpi_1_1status.html", "structgko_1_1experimental_1_1mpi_1_1status" ],
           [ "type_impl", "structgko_1_1experimental_1_1mpi_1_1type__impl.html", null ],
@@ -118,9 +122,7 @@ var annotated_dup =
         ] ],
         [ "solver", null, [
           [ "Direct", "classgko_1_1experimental_1_1solver_1_1Direct.html", "classgko_1_1experimental_1_1solver_1_1Direct" ]
-        ] ],
-        [ "EnableDistributedLinOp", "classgko_1_1experimental_1_1EnableDistributedLinOp.html", null ],
-        [ "EnableDistributedPolymorphicObject", "classgko_1_1experimental_1_1EnableDistributedPolymorphicObject.html", null ]
+        ] ]
       ] ],
       [ "factorization", "namespacegko_1_1factorization.html", [
         [ "Ic", "classgko_1_1factorization_1_1Ic.html", "classgko_1_1factorization_1_1Ic" ],
@@ -199,6 +201,7 @@ var annotated_dup =
         [ "CbGmres", "classgko_1_1solver_1_1CbGmres.html", "classgko_1_1solver_1_1CbGmres" ],
         [ "Cg", "classgko_1_1solver_1_1Cg.html", "classgko_1_1solver_1_1Cg" ],
         [ "Cgs", "classgko_1_1solver_1_1Cgs.html", "classgko_1_1solver_1_1Cgs" ],
+        [ "Chebyshev", "classgko_1_1solver_1_1Chebyshev.html", "classgko_1_1solver_1_1Chebyshev" ],
         [ "enable_iterative_solver_factory_parameters", "structgko_1_1solver_1_1enable__iterative__solver__factory__parameters.html", "structgko_1_1solver_1_1enable__iterative__solver__factory__parameters" ],
         [ "enable_preconditioned_iterative_solver_factory_parameters", "structgko_1_1solver_1_1enable__preconditioned__iterative__solver__factory__parameters.html", "structgko_1_1solver_1_1enable__preconditioned__iterative__solver__factory__parameters" ],
         [ "EnableApplyWithInitialGuess", "classgko_1_1solver_1_1EnableApplyWithInitialGuess.html", null ],
@@ -214,7 +217,9 @@ var annotated_dup =
         [ "Ir", "classgko_1_1solver_1_1Ir.html", "classgko_1_1solver_1_1Ir" ],
         [ "IterativeBase", "classgko_1_1solver_1_1IterativeBase.html", "classgko_1_1solver_1_1IterativeBase" ],
         [ "LowerTrs", "classgko_1_1solver_1_1LowerTrs.html", "classgko_1_1solver_1_1LowerTrs" ],
+        [ "Minres", "classgko_1_1solver_1_1Minres.html", "classgko_1_1solver_1_1Minres" ],
         [ "Multigrid", "classgko_1_1solver_1_1Multigrid.html", "classgko_1_1solver_1_1Multigrid" ],
+        [ "PipeCg", "classgko_1_1solver_1_1PipeCg.html", "classgko_1_1solver_1_1PipeCg" ],
         [ "SolverBase", "classgko_1_1solver_1_1SolverBase.html", "classgko_1_1solver_1_1SolverBase" ],
         [ "UpperTrs", "classgko_1_1solver_1_1UpperTrs.html", "classgko_1_1solver_1_1UpperTrs" ],
         [ "workspace_traits", "structgko_1_1solver_1_1workspace__traits.html", null ],
@@ -222,6 +227,7 @@ var annotated_dup =
         [ "workspace_traits< Bicgstab< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Bicgstab_3_01ValueType_01_4_01_4.html", null ],
         [ "workspace_traits< Cg< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Cg_3_01ValueType_01_4_01_4.html", null ],
         [ "workspace_traits< Cgs< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Cgs_3_01ValueType_01_4_01_4.html", null ],
+        [ "workspace_traits< Chebyshev< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Chebyshev_3_01ValueType_01_4_01_4.html", null ],
         [ "workspace_traits< Fcg< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Fcg_3_01ValueType_01_4_01_4.html", null ],
         [ "workspace_traits< Gcr< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Gcr_3_01ValueType_01_4_01_4.html", null ],
         [ "workspace_traits< gko::experimental::solver::Direct< ValueType, IndexType > >", "structgko_1_1solver_1_1workspace__traits_3_01gko_1_1experimental_1_1solver_1_1Direct_3_01ValueType_00_01IndexType_01_4_01_4.html", null ],
@@ -229,7 +235,9 @@ var annotated_dup =
         [ "workspace_traits< Idr< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Idr_3_01ValueType_01_4_01_4.html", null ],
         [ "workspace_traits< Ir< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Ir_3_01ValueType_01_4_01_4.html", null ],
         [ "workspace_traits< LowerTrs< ValueType, IndexType > >", "structgko_1_1solver_1_1workspace__traits_3_01LowerTrs_3_01ValueType_00_01IndexType_01_4_01_4.html", null ],
+        [ "workspace_traits< Minres< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Minres_3_01ValueType_01_4_01_4.html", null ],
         [ "workspace_traits< Multigrid >", "structgko_1_1solver_1_1workspace__traits_3_01Multigrid_01_4.html", null ],
+        [ "workspace_traits< PipeCg< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01PipeCg_3_01ValueType_01_4_01_4.html", null ],
         [ "workspace_traits< UpperTrs< ValueType, IndexType > >", "structgko_1_1solver_1_1workspace__traits_3_01UpperTrs_3_01ValueType_00_01IndexType_01_4_01_4.html", null ]
       ] ],
       [ "stop", "namespacegko_1_1stop.html", [
@@ -250,6 +258,9 @@ var annotated_dup =
         [ "type_list", "structgko_1_1syn_1_1type__list.html", null ],
         [ "value_list", "structgko_1_1syn_1_1value__list.html", null ]
       ] ],
+      [ "xstd", "namespacegko_1_1xstd.html", [
+        [ "type_identity", "structgko_1_1xstd_1_1type__identity.html", null ]
+      ] ],
       [ "AbsoluteComputable", "classgko_1_1AbsoluteComputable.html", "classgko_1_1AbsoluteComputable" ],
       [ "AbstractFactory", "classgko_1_1AbstractFactory.html", "classgko_1_1AbstractFactory" ],
       [ "AllocationError", "classgko_1_1AllocationError.html", "classgko_1_1AllocationError" ],
@@ -260,6 +271,7 @@ var annotated_dup =
       [ "array", "classgko_1_1array.html", "classgko_1_1array" ],
       [ "BadDimension", "classgko_1_1BadDimension.html", "classgko_1_1BadDimension" ],
       [ "batch_dim", "structgko_1_1batch__dim.html", "structgko_1_1batch__dim" ],
+      [ "bfloat16", "classgko_1_1bfloat16.html", null ],
       [ "BlockOperator", "classgko_1_1BlockOperator.html", "classgko_1_1BlockOperator" ],
       [ "BlockSizeError", "classgko_1_1BlockSizeError.html", "classgko_1_1BlockSizeError" ],
       [ "Combination", "classgko_1_1Combination.html", "classgko_1_1Combination" ],
@@ -288,7 +300,7 @@ var annotated_dup =
       [ "DiagonalExtractable", "classgko_1_1DiagonalExtractable.html", "classgko_1_1DiagonalExtractable" ],
       [ "DiagonalLinOpExtractable", "classgko_1_1DiagonalLinOpExtractable.html", "classgko_1_1DiagonalLinOpExtractable" ],
       [ "dim", "structgko_1_1dim.html", "structgko_1_1dim" ],
-      [ "dim< 1u, DimensionType >", "structgko_1_1dim_3_011u_00_01DimensionType_01_4.html", "structgko_1_1dim_3_011u_00_01DimensionType_01_4" ],
+      [ "dim< 1u, DimensionType >", "structgko_1_1dim_3_011u_00_01DimensionType_01_4.html", null ],
       [ "DimensionMismatch", "classgko_1_1DimensionMismatch.html", "classgko_1_1DimensionMismatch" ],
       [ "DpcppExecutor", "classgko_1_1DpcppExecutor.html", "classgko_1_1DpcppExecutor" ],
       [ "DpcppTimer", "classgko_1_1DpcppTimer.html", "classgko_1_1DpcppTimer" ],
@@ -304,7 +316,7 @@ var annotated_dup =
       [ "Error", "classgko_1_1Error.html", "classgko_1_1Error" ],
       [ "Executor", "classgko_1_1Executor.html", "classgko_1_1Executor" ],
       [ "executor_deleter", "classgko_1_1executor__deleter.html", "classgko_1_1executor__deleter" ],
-      [ "executor_deleter< T[]>", "classgko_1_1executor__deleter_3_01T_0f_0e_4.html", "classgko_1_1executor__deleter_3_01T_0f_0e_4" ],
+      [ "executor_deleter< T[]>", "classgko_1_1executor__deleter_3_01T_0f_0e_4.html", null ],
       [ "half", "classgko_1_1half.html", null ],
       [ "hip_stream", "classgko_1_1hip__stream.html", "classgko_1_1hip__stream" ],
       [ "HipAllocator", "classgko_1_1HipAllocator.html", null ],
@@ -334,7 +346,7 @@ var annotated_dup =
       [ "NotImplemented", "classgko_1_1NotImplemented.html", "classgko_1_1NotImplemented" ],
       [ "NotSupported", "classgko_1_1NotSupported.html", "classgko_1_1NotSupported" ],
       [ "null_deleter", "classgko_1_1null__deleter.html", "classgko_1_1null__deleter" ],
-      [ "null_deleter< T[]>", "classgko_1_1null__deleter_3_01T_0f_0e_4.html", "classgko_1_1null__deleter_3_01T_0f_0e_4" ],
+      [ "null_deleter< T[]>", "classgko_1_1null__deleter_3_01T_0f_0e_4.html", null ],
       [ "nvidia_device", "classgko_1_1nvidia__device.html", null ],
       [ "OmpExecutor", "classgko_1_1OmpExecutor.html", "classgko_1_1OmpExecutor" ],
       [ "Operation", "classgko_1_1Operation.html", "classgko_1_1Operation" ],
