@@ -6,6 +6,7 @@ var classgko_1_1matrix_1_1Coo =
     [ "apply2", "classgko_1_1matrix_1_1Coo.html#ac3829de9d2b933db4fee6e2f55d99fda", null ],
     [ "compute_absolute", "classgko_1_1matrix_1_1Coo.html#ac40e048a11f6eaa698e01fa59dbc82e8", null ],
     [ "compute_absolute_inplace", "classgko_1_1matrix_1_1Coo.html#aa3be345b0334650e50857c21837e0e07", null ],
+    [ "conj_transpose", "classgko_1_1matrix_1_1Coo.html#a77810f90e29b3745f352a4c42c44bcfc", null ],
     [ "extract_diagonal", "classgko_1_1matrix_1_1Coo.html#af12b1d22ad6851193c0f17e52d650180", null ],
     [ "get_col_idxs", "classgko_1_1matrix_1_1Coo.html#a1da460bd20cc25ce1ae512b6a45243d1", null ],
     [ "get_const_col_idxs", "classgko_1_1matrix_1_1Coo.html#a2fc6fb6cc3b8dcaa58034f12ff1b6929", null ],
@@ -13,5 +14,6 @@ var classgko_1_1matrix_1_1Coo =
     [ "get_const_values", "classgko_1_1matrix_1_1Coo.html#aadb3e83f3f76e9b3e7a5532eced05c86", null ],
     [ "get_num_stored_elements", "classgko_1_1matrix_1_1Coo.html#aece531e069f8490fd8d2b3ab58f72d09", null ],
     [ "get_row_idxs", "classgko_1_1matrix_1_1Coo.html#af15ca89ba01c50f7d496b6b6ff866700", null ],
-    [ "get_values", "classgko_1_1matrix_1_1Coo.html#af6903756353277547ac24da81b9b9eba", null ]
+    [ "get_values", "classgko_1_1matrix_1_1Coo.html#af6903756353277547ac24da81b9b9eba", null ],
+    [ "transpose", "classgko_1_1matrix_1_1Coo.html#a2430e61f85b0d5b71a15281f2480d9ce", null ]
 ];
\ No newline at end of file
