@@ -12,9 +12,7 @@ var namespacegko =
     [ "experimental", null, [
       [ "distributed", "namespacegko_1_1experimental_1_1distributed.html", "namespacegko_1_1experimental_1_1distributed" ],
       [ "mpi", "namespacegko_1_1experimental_1_1mpi.html", "namespacegko_1_1experimental_1_1mpi" ],
-      [ "reorder", "namespacegko_1_1experimental_1_1reorder.html", "namespacegko_1_1experimental_1_1reorder" ],
-      [ "EnableDistributedLinOp", "classgko_1_1experimental_1_1EnableDistributedLinOp.html", null ],
-      [ "EnableDistributedPolymorphicObject", "classgko_1_1experimental_1_1EnableDistributedPolymorphicObject.html", null ]
+      [ "reorder", "namespacegko_1_1experimental_1_1reorder.html", "namespacegko_1_1experimental_1_1reorder" ]
     ] ],
     [ "factorization", "namespacegko_1_1factorization.html", "namespacegko_1_1factorization" ],
     [ "log", "namespacegko_1_1log.html", "namespacegko_1_1log" ],
@@ -29,9 +27,7 @@ var namespacegko =
     [ "solver", "namespacegko_1_1solver.html", "namespacegko_1_1solver" ],
     [ "stop", "namespacegko_1_1stop.html", "namespacegko_1_1stop" ],
     [ "syn", "namespacegko_1_1syn.html", "namespacegko_1_1syn" ],
-    [ "xstd", "namespacegko_1_1xstd.html", [
-      [ "void_t", "namespacegko_1_1xstd.html#a2d53b45325a9d6c46906d80caf180869", null ]
-    ] ],
+    [ "xstd", "namespacegko_1_1xstd.html", "namespacegko_1_1xstd" ],
     [ "AbsoluteComputable", "classgko_1_1AbsoluteComputable.html", "classgko_1_1AbsoluteComputable" ],
     [ "AbstractFactory", "classgko_1_1AbstractFactory.html", "classgko_1_1AbstractFactory" ],
     [ "AllocationError", "classgko_1_1AllocationError.html", "classgko_1_1AllocationError" ],
@@ -42,6 +38,7 @@ var namespacegko =
     [ "array", "classgko_1_1array.html", "classgko_1_1array" ],
     [ "BadDimension", "classgko_1_1BadDimension.html", "classgko_1_1BadDimension" ],
     [ "batch_dim", "structgko_1_1batch__dim.html", "structgko_1_1batch__dim" ],
+    [ "bfloat16", "classgko_1_1bfloat16.html", null ],
     [ "BlockOperator", "classgko_1_1BlockOperator.html", "classgko_1_1BlockOperator" ],
     [ "BlockSizeError", "classgko_1_1BlockSizeError.html", "classgko_1_1BlockSizeError" ],
     [ "Combination", "classgko_1_1Combination.html", "classgko_1_1Combination" ],
@@ -70,7 +67,7 @@ var namespacegko =
     [ "DiagonalExtractable", "classgko_1_1DiagonalExtractable.html", "classgko_1_1DiagonalExtractable" ],
     [ "DiagonalLinOpExtractable", "classgko_1_1DiagonalLinOpExtractable.html", "classgko_1_1DiagonalLinOpExtractable" ],
     [ "dim", "structgko_1_1dim.html", "structgko_1_1dim" ],
-    [ "dim< 1u, DimensionType >", "structgko_1_1dim_3_011u_00_01DimensionType_01_4.html", "structgko_1_1dim_3_011u_00_01DimensionType_01_4" ],
+    [ "dim< 1u, DimensionType >", "structgko_1_1dim_3_011u_00_01DimensionType_01_4.html", null ],
     [ "DimensionMismatch", "classgko_1_1DimensionMismatch.html", "classgko_1_1DimensionMismatch" ],
     [ "DpcppExecutor", "classgko_1_1DpcppExecutor.html", "classgko_1_1DpcppExecutor" ],
     [ "DpcppTimer", "classgko_1_1DpcppTimer.html", "classgko_1_1DpcppTimer" ],
@@ -86,7 +83,7 @@ var namespacegko =
     [ "Error", "classgko_1_1Error.html", "classgko_1_1Error" ],
     [ "Executor", "classgko_1_1Executor.html", "classgko_1_1Executor" ],
     [ "executor_deleter", "classgko_1_1executor__deleter.html", "classgko_1_1executor__deleter" ],
-    [ "executor_deleter< T[]>", "classgko_1_1executor__deleter_3_01T_0f_0e_4.html", "classgko_1_1executor__deleter_3_01T_0f_0e_4" ],
+    [ "executor_deleter< T[]>", "classgko_1_1executor__deleter_3_01T_0f_0e_4.html", null ],
     [ "half", "classgko_1_1half.html", null ],
     [ "hip_stream", "classgko_1_1hip__stream.html", "classgko_1_1hip__stream" ],
     [ "HipAllocator", "classgko_1_1HipAllocator.html", null ],
@@ -116,7 +113,7 @@ var namespacegko =
     [ "NotImplemented", "classgko_1_1NotImplemented.html", "classgko_1_1NotImplemented" ],
     [ "NotSupported", "classgko_1_1NotSupported.html", "classgko_1_1NotSupported" ],
     [ "null_deleter", "classgko_1_1null__deleter.html", "classgko_1_1null__deleter" ],
-    [ "null_deleter< T[]>", "classgko_1_1null__deleter_3_01T_0f_0e_4.html", "classgko_1_1null__deleter_3_01T_0f_0e_4" ],
+    [ "null_deleter< T[]>", "classgko_1_1null__deleter_3_01T_0f_0e_4.html", null ],
     [ "nvidia_device", "classgko_1_1nvidia__device.html", null ],
     [ "OmpExecutor", "classgko_1_1OmpExecutor.html", "classgko_1_1OmpExecutor" ],
     [ "Operation", "classgko_1_1Operation.html", "classgko_1_1Operation" ],
@@ -161,8 +158,9 @@ var namespacegko =
     [ "int8", "namespacegko.html#a7ff694002fd7739ee5c4c03f4159c3ca", null ],
     [ "is_complex_or_scalar_s", "namespacegko.html#abf707c1057eb7f959355ab06990441a8", null ],
     [ "is_complex_s", "namespacegko.html#a700d12db3a341bb7a46bede49e1d6715", null ],
-    [ "next_precision", "namespacegko.html#a3b2eb507e35d2ef030c8392229772b75", null ],
+    [ "next_precision", "namespacegko.html#aee37f85b217e5e26fe64207d41fa4bac", null ],
     [ "next_precision_base", "namespacegko.html#a2c2416a808014f8b0647d5e4ba42a735", null ],
+    [ "previous_precision", "namespacegko.html#ada2119004771922e8f7fcb6910a0363c", null ],
     [ "previous_precision_base", "namespacegko.html#a7f9e0f5413aca83838f94cbe9863e15c", null ],
     [ "reduce_precision", "namespacegko.html#a87a96a1b78352538d905c10518bf5571", null ],
     [ "remove_complex", "namespacegko.html#a107302a750bfa82a2107c77293f791c9", null ],
