@@ -1,5 +1,6 @@
 var searchData=
 [
   ['jacobi_0',['Jacobi',['../classgko_1_1batch_1_1preconditioner_1_1Jacobi.html',1,'gko::batch::preconditioner::Jacobi&lt; ValueType, IndexType &gt;'],['../classgko_1_1preconditioner_1_1Jacobi.html',1,'gko::preconditioner::Jacobi&lt; ValueType, IndexType &gt;'],['../classgko_1_1preconditioner_1_1Jacobi.html#a51fb3164a0886cb3c48b3c26c6af7513',1,'gko::preconditioner::Jacobi::Jacobi(const Jacobi &amp;other)'],['../classgko_1_1preconditioner_1_1Jacobi.html#a747ca4267e56029521a80410c64a2f13',1,'gko::preconditioner::Jacobi::Jacobi(Jacobi &amp;&amp;other)']]],
-  ['jacobi_20preconditioner_1',['Jacobi Preconditioner',['../group__jacobi.html',1,'']]]
+  ['jacobi_20preconditioner_1',['Jacobi Preconditioner',['../group__jacobi.html',1,'']]],
+  ['jacobi_3c_20valuetype_2c_20indextype_20_3e_2',['Jacobi&lt; ValueType, IndexType &gt;',['../classgko_1_1preconditioner_1_1Jacobi.html',1,'gko::preconditioner']]]
 ];
