@@ -11,7 +11,7 @@ var searchData=
   ['variable_20declarations_8',['Variable declarations',['../contributing_guidelines.html#autotoc_md46',1,'']]],
   ['variables_9',['Variables',['../contributing_guidelines.html#autotoc_md33',1,'']]],
   ['vector_10',['Vector',['../classgko_1_1experimental_1_1distributed_1_1Vector.html',1,'gko::experimental::distributed']]],
-  ['vector_3c_20previous_5fprecision_5fbase_3c_20valuetype_20_3e_20_3e_11',['Vector&lt; previous_precision_base&lt; ValueType &gt; &gt;',['../classgko_1_1experimental_1_1distributed_1_1Vector.html',1,'gko::experimental::distributed']]],
+  ['vector_3c_20previous_5fprecision_3c_20valuetype_20_3e_20_3e_11',['Vector&lt; previous_precision&lt; ValueType &gt; &gt;',['../classgko_1_1experimental_1_1distributed_1_1Vector.html',1,'gko::experimental::distributed']]],
   ['vector_3c_20to_5fcomplex_3c_20value_5ftype_20_3e_20_3e_12',['Vector&lt; to_complex&lt; value_type &gt; &gt;',['../classgko_1_1experimental_1_1distributed_1_1Vector.html',1,'gko::experimental::distributed']]],
   ['vector_3c_20valuetype_20_3e_13',['Vector&lt; ValueType &gt;',['../classgko_1_1experimental_1_1distributed_1_1Vector.html',1,'gko::experimental::distributed']]],
   ['version_14',['version',['../structgko_1_1version.html',1,'gko']]],
