@@ -10,7 +10,7 @@ var searchData=
   ['blockoperator_7',['BlockOperator',['../classgko_1_1BlockOperator.html#acb8ff1788a332231a3e9f8199dec0d03',1,'gko::BlockOperator::BlockOperator(const BlockOperator &amp;other)'],['../classgko_1_1BlockOperator.html#a4066b33a9d42462429c76eea3f9532c1',1,'gko::BlockOperator::BlockOperator(BlockOperator &amp;&amp;other) noexcept']]],
   ['blocksizeerror_8',['BlockSizeError',['../classgko_1_1BlockSizeError.html#a861999cfafdd726814ef4bcd06734bd7',1,'gko::BlockSizeError']]],
   ['broadcast_9',['broadcast',['../classgko_1_1experimental_1_1mpi_1_1communicator.html#a95ea693d1ddc249215968d378e80dcc7',1,'gko::experimental::mpi::communicator']]],
-  ['build_10',['build',['../classgko_1_1experimental_1_1factorization_1_1Cholesky.html#a154cada7f11335b0148b946e3b6ad85f',1,'gko::experimental::factorization::Cholesky::build()'],['../classgko_1_1experimental_1_1factorization_1_1Lu.html#a61cd8064ed1566c54912183bfeae5e5e',1,'gko::experimental::factorization::Lu::build()'],['../classgko_1_1experimental_1_1reorder_1_1Amd.html#a03fa10a26c275d6aa5e87c97836f3169',1,'gko::experimental::reorder::Amd::build()'],['../classgko_1_1experimental_1_1reorder_1_1Mc64.html#acf4ff0eb6edb11ea44b9745ece9ded65',1,'gko::experimental::reorder::Mc64::build()'],['../classgko_1_1experimental_1_1reorder_1_1Rcm.html#a6be4bed40dd659bc915f4320c6f1ab81',1,'gko::experimental::reorder::Rcm::build()']]],
+  ['build_10',['build',['../classgko_1_1experimental_1_1factorization_1_1Cholesky.html#a154cada7f11335b0148b946e3b6ad85f',1,'gko::experimental::factorization::Cholesky::build()'],['../classgko_1_1experimental_1_1factorization_1_1Lu.html#a61cd8064ed1566c54912183bfeae5e5e',1,'gko::experimental::factorization::Lu::build()'],['../classgko_1_1preconditioner_1_1GaussSeidel.html#a7dbce0fc2e2e9a1eaca030a9f368b739',1,'gko::preconditioner::GaussSeidel::build()'],['../classgko_1_1preconditioner_1_1Sor.html#a23c746f50487fe2824c3957995645099',1,'gko::preconditioner::Sor::build()'],['../classgko_1_1experimental_1_1reorder_1_1Amd.html#a03fa10a26c275d6aa5e87c97836f3169',1,'gko::experimental::reorder::Amd::build()'],['../classgko_1_1experimental_1_1reorder_1_1Mc64.html#acf4ff0eb6edb11ea44b9745ece9ded65',1,'gko::experimental::reorder::Mc64::build()'],['../classgko_1_1experimental_1_1reorder_1_1Rcm.html#a6be4bed40dd659bc915f4320c6f1ab81',1,'gko::experimental::reorder::Rcm::build()']]],
   ['build_5ffrom_5fcontiguous_11',['build_from_contiguous',['../classgko_1_1experimental_1_1distributed_1_1Partition.html#acbc987df113d50d6cdf6d6b605a15860',1,'gko::experimental::distributed::Partition']]],
   ['build_5ffrom_5fglobal_5fsize_5funiform_12',['build_from_global_size_uniform',['../classgko_1_1experimental_1_1distributed_1_1Partition.html#a54bfa82bec475057cba794814342505e',1,'gko::experimental::distributed::Partition']]],
   ['build_5ffrom_5fmapping_13',['build_from_mapping',['../classgko_1_1experimental_1_1distributed_1_1Partition.html#ad17d1164a99bca5df2d2ec0eb5d79c2f',1,'gko::experimental::distributed::Partition']]],
