@@ -10,7 +10,7 @@ var indexSectionsWithContent =
   7: "acfilmnoprsuz",
   8: "o",
   9: "bcdefhjlmoprs",
-  10: "abcdefghiklmnoprst"
+  10: "1234567abcdefghiklmnopqrstuvw"
 };
 
 var indexSectionNames =
